(function () {

  // simple sanity check that there is a non-empty selection
  if (!app.selection || !app.selection.length)
    return;

  // load the building list, create an options array
  var buildinglist = [];
  var buildingfile = bundle.load("buildings.txt");
  buildingfile.forEach(function (line) {
    if (line && line.length)
      buildinglist.push({ label: line, value: line });
  });

  return({
    // version of the object for behavior consistency
    version: 1,
    // setup object describing what we want from the user
    setup: {
      fields: [
        {
          // first and only field is for the building
          id: "building",
          label: "Building:",
          type: "menu",
          options: buildinglist,
          default: localStorage.getItem("building"),
          required: true
        }
      ]
    },
    // proceed function to be called once input is complete
    proceed: function (params) {
      localStorage.setItem("building", params.building);

      // iterate through the objects in the selection
      app.selection.forEach({
        context: params,    // params becomes this in the callback
        callback: function (obj) {
          // set the property
          obj.usr0 = this.building;
          // save the changes
          obj.commit();
        }
      });

      var viewport = new KSViewport("computer", "Building Set to " + params.building);
      viewport.select(app.selection);
      viewport.show();
    }
  });

})();
